Installation
============

To install from PyPI run - ::

   pip install footings


To install the latest version on github run - ::

   pip install git+https://github.com/foootings/footings-core.git
